@@ -39,7 +39,7 @@ class Scenario:
       self._continue_scenario(j)
     elif "squeued" in res:
       while True:
-        try: res = Scenario._decode_json(self.srv._waits_for(buffer_size))
+        try: res = Scenario._decode_json(self.srv._waits_for())
         except UnicodeDecodeError: print('Unicode decode error.')
         if "stoken" not in res: raise ScenarioNotStartedException
         self.token = res["stoken"]
